ShardShutdownStats

Struct ShardShutdownStats 

pub struct ShardShutdownStats {
    pub initial_commits_enqueued: usize,
    pub excess_execute_if_cacheds: usize,
    pub excess_execute_muts: usize,
    pub excess_executes: usize,
    pub take_data_requests: usize,
    pub loads_completed: usize,
    pub loads_failed: usize,
    pub commits_completed: usize,
    pub commits_failed: usize,
}

Fields

initial_commits_enqueued: usize

The number of commits in the commit queue at the time of the first graceful shutdown signal

excess_execute_if_cacheds: usize

The number of ExecuteIfCached calls after the first graceful shutdown signal

excess_execute_muts: usize

The number of ExecuteMut calls after the first graceful shutdown signal

excess_executes: usize

The number of Execute calls after the first graceful shutdown signal

take_data_requests: usize

The number of TakeData requests made after the first graceful shutdown signal

loads_completed: usize

The number of load tasks completed during the shutdown drain

loads_failed: usize

The number of load tasks failed during the shutdown drain

commits_completed: usize

The number of commit tasks completed during the shutdown drain

commits_failed: usize

The number of commit tasks failed during the shutdown drain